@@ -1,6 +1,6 @@
 package Pod::Query;
 
-use v5.24;                # Postfix defef :)
+use v5.24;    # Postfix defef :)
 use strict;
 use warnings;
 use File::Spec::Functions qw( catfile );
@@ -9,7 +9,7 @@ use Text::ParseWords      qw( parse_line );
 use Mojo::Base            qw( -base );
 use Mojo::Util            qw( dumper class_to_path );
 use Mojo::ByteStream      qw( b );
-use Term::Size::Any();    # chars().
+use Term::Size::Any       qw( chars );
 use Pod::Text();
 use Pod::LOL;
 
@@ -19,11 +19,11 @@ Pod::Query - Query pod documents
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =cut
 
-our $VERSION                   = '0.23';
+our $VERSION                   = '0.24';
 our $DEBUG_LOL_DUMP            = 0;
 our $DEBUG_STRUCT_OVER         = 0;
 our $DEBUG_TREE                = 0;
@@ -127,7 +127,6 @@ sub new {
     $s;
 }
 
-
 =head2 _class_to_path
 
 Given a class name, returns the path to the pod file.
@@ -173,7 +172,6 @@ sub _class_to_path {
     return "";
 }
 
-
 =head2 _mock_root
 
 For debugging and/or testing.
@@ -296,7 +294,6 @@ sub _lol_to_tree {
     \@tree;
 }
 
-
 =head2 _define_heads_regex_table
 
 Generates the regexes for head elements inside
@@ -313,7 +310,6 @@ sub _define_heads_regex_table {
     } 1 .. 4;
 }
 
-
 =head2 _make_leaf
 
 Creates a new node (aka leaf).
@@ -338,7 +334,6 @@ sub _make_leaf {
     $leaf;
 }
 
-
 =head2 _structure_over
 
 Restructures the text for an "over-text" element to be under it.
@@ -382,7 +377,6 @@ sub _structure_over {
     \@struct;
 }
 
-
 =head2 find_title
 
 Extracts the title information.
@@ -394,7 +388,6 @@ sub find_title {
     scalar $s->find( 'head1=NAME[0]/Para[0]' );
 }
 
-
 =head2 find_method
 
 Extracts the complete method information.
@@ -408,7 +401,6 @@ sub find_method {
     $s->find( sprintf '~head=~^%s\b.*$[0]**', $m );
 }
 
-
 =head2 find_method_summary
 
 Extracts the method summary.
@@ -441,7 +433,6 @@ sub _clean_method_name {
     $clean;
 }
 
-
 =head2 find_events
 
 Extracts a list of events with a description.
@@ -455,7 +446,6 @@ sub find_events {
     $s->find( '~head=EVENTS[0]/~head*/(Para)[0]' );
 }
 
-
 =head2 find
 
 Generic extraction command.
@@ -541,7 +531,6 @@ sub find {
     _render( $kept_all, @tree );
 }
 
-
 =head2 _query_string_to_struct
 
 Convert a pod query string into a structure based on these rules:
@@ -632,7 +621,6 @@ sub _query_string_to_struct {
     \@query_struct;
 }
 
-
 =head2 _check_conditions
 
 Check if queries are valid.
@@ -687,7 +675,6 @@ sub _check_conditions {
     }
 }
 
-
 =head2 _set_condition_defaults
 
 Assigns default query options.
@@ -743,7 +730,6 @@ sub _set_condition_defaults {
     }
 }
 
-
 =head2 _find
 
 Lower level find command.
@@ -857,7 +843,6 @@ sub _find {
     @found;
 }
 
-
 =head2 _invert
 
 Previous elements are inside of the child
@@ -914,7 +899,6 @@ sub _invert {
     @tree;
 }
 
-
 =head2 _render
 
 Transforms a tree of found nodes in a simple list
@@ -999,7 +983,6 @@ sub get_term_width {
     $term_width;
 }
 
-
 =head1 SEE ALSO
 
 L<App::Pod>
